import sys, os, unittest
sys.path.append(os.path.abspath("./"))
sys.path.append(os.path.abspath("../"))
from libgs import Geos


class TestChina(unittest.TestCase):

    def test_Provinces(self):
        res = Geos().search("北京", depth=1)
        self.assertEqual(res[0].name, '北京市')

if __name__ == '__main__':
    unittest.main()


from .db import DBCreator

class Geos:
    def __init__(self):
        self.databases = DBCreator()

    def findall(self, key: str, depth = 1):
        res = []
        for db in self.databases:
            for i in db.findAll(key, depth):
                res.append(i)
        return res
    

    def findone(self, key: str, depth = 1):
        for db in self.databases:
            for i in db.findAll(key, depth):
                return i
                


from typing import List
from .model import Province, City, Area, Street, Village
import sqlite3, os

# DB 接口
class Interface():
    def findAll(self):
        pass

# GeosDB
class GeosDB(Interface):
    def __init__(self, db: sqlite3.Connection):
        self._db = db

    def shortName(self, name: str):
        data = self.execSelect(f"SELECT ShortName FROM extra WHERE Name = '{name}'")
        return data[0][0]

    # provinces 省级查询
    def provinces(self, key:str):
        data = self.execSelect(f"SELECT code,name FROM province WHERE name LIKE '%{key}%'")
        return [Province(code=item[0], name=item[1], shortName=self.shortName(item[1])) for item in data]
    
    # cities 市级查询
    def cities(self, key: str):
        data = self.execSelect(f"SELECT code,name FROM city WHERE name LIKE '%{key}%'")
        return [City(code=item[0], name=item[1],shortName=self.shortName(item[1])) for item in data]
    
    # areas 县界查询
    def areas(self, key:str):
        data = self.execSelect(f"SELECT code,name FROM area WHERE name LIKE '%{key}%'")
        return [Area(code=item[0], name=item[1],shortName=self.shortName(item[1])) for item in data]

    # streets 乡级查询
    def streets(self, key:str):
        data = self.execSelect(f"SELECT code,name FROM street WHERE name LIKE '%{key}%'")
        return [Street(code=item[0], name=item[1],shortName=self.shortName(item[1])) for item in data]

    # villages 村级查询
    def villages(self, key:str):
        data = self.execSelect(f"SELECT code,name FROM street WHERE name LIKE '%{key}%'")
        return [Village(code=item[0], name=item[1],shortName=self.shortName(item[1])) for item in data]
    
    def commad(self)->List:
        return [
            self.provinces,
            self.cities,
            self.areas,
            self.streets,
            self.villages
        ]

    def execSelect(self, selectSql:str):
        cursor = self._db.cursor()
        cursor.execute(selectSql)
        result = cursor.fetchall()
        cursor.close()
        return result

    def findAll(self, key: str, depth:int):
        result = []
        commad = self.commad()
        for i in range(depth):
            for res in commad[i](key):
                result.append(res)
        return result


def DBCreator() ->List[Interface]:
    basePath = os.path.abspath(os.path.join(__file__, os.path.pardir, os.path.pardir,"db"))
    return [
        GeosDB(sqlite3.connect(os.path.join(basePath, './china.sqlite')))
    ]

__all__ = ["DBCreator"]


#!/usr/bin/env python
import io
from setuptools import setup, find_packages

version = "0.0.2"

setup(
    name="meltingGeos",
    version=version,
    url='https://github.com/arrebole/meltingGeos',
    description='Find standard city info names by obfuscated names;',
    packages=find_packages(),
    keywords="meltingGeos",
)



class Province:
    def __init__(self, code: str, name: str, shortName: str):
        self.type = "province"
        self.code = code
        self.name = name
        self.shortName = shortName
    
    def __str__(self) ->str:
        return f"type: ‘{self.type}', code: '{self.code}', name: '{self.name}', shortName: '{self.shortName}'"
    
    def __repr__(self) ->str:
        return f"type: '{self.type}'', code: '{self.code}', name: '{self.name}', shortName: '{self.shortName}'"
    

class City:
    def __init__(self, code: str, name: str, shortName: str):
        self.type = "city"
        self.code = code
        self.name = name
        self.shortName = shortName
    
    def __str__(self) ->str:
        return f"type: '{self.type}', code: '{self.code}', name: '{self.name}', shortName: '{self.shortName}'"
    
    def __repr__(self) ->str:
        return f"type: '{self.type}', code: '{self.code}', name: '{self.name}', shortName: '{self.shortName}'"


class Area:
    def __init__(self, code: str, name: str, shortName: str):
        self.type = "area"
        self.code = code
        self.name = name
        self.shortName = shortName
    
    def __str__(self) ->str:
        return f"type: '{self.type}', code: '{self.code}'', name: '{self.name}', shortName: '{self.shortName}'"
    
    def __repr__(self) ->str:
        return f"type: '{self.type}', code: '{self.code}'', name: '{self.name}', shortName: '{self.shortName}'"


class Street:
    def __init__(self, code: str, name: str, shortName: str):
        self.type = "street"
        self.code = code
        self.name = name
        self.shortName = shortName
    
    def __str__(self) ->str:
        return f"type: '{self.type}', code: '{self.code}', name: '{self.name}', shortName: '{self.shortName}'"
    
    def __repr__(self) ->str:
        return f"type: '{self.type}', code: '{self.code}', name: '{self.name}', shortName: '{self.shortName}'"


class Village:
    def __init__(self, code: str, name: str, shortName: str):
        self.type = "villages"
        self.code = code
        self.name = name
        self.shortName = shortName
    
    def __str__(self) ->str:
        return f"type: '{self.type}'', code: '{self.code}'', name: '{self.name}', shortName: '{self.shortName}'"
    
    def __repr__(self) ->str:
        return f"type: '{self.type}'', code: '{self.code}'', name: '{self.name}', shortName: '{self.shortName}'"